@@ -49,6 +49,26 @@ def _distance(x:torch.Tensor , y:torch.Tensor, type:str='cosine')->torch.Tensor:
             raise NameError('{} not recognized as valid distance. Acceptable values are:[\'cosine\',\'l2\',\'dot\']'.format(type))
         return d
 
+
+class MLP(nn.Module):
+    '''
+    Multi-layer perceptron class
+    '''
+    def __init__(self, input_size, hidden_size, output_size):
+        super(MLP, self).__init__()
+        self.input_size = input_size
+        self.hidden_size  = hidden_size
+        self.fc1 = torch.nn.Linear(self.input_size, self.hidden_size)
+        self.relu = torch.nn.ReLU()
+        self.fc2 = torch.nn.Linear(self.hidden_size, output_size)
+    
+    def forward(self, x):
+        hidden = self.fc1(x)
+        relu = self.relu(hidden)
+        output = self.fc2(relu)
+        return output
+
+
 class MemoryWrapLayer(nn.Module):
 
     def __init__(self, encoder_output_dim:int, output_dim:int, head: torch.nn.Module=None, classifier:torch.nn.Module=None,distance:str='cosine'):
@@ -64,12 +84,7 @@ class MemoryWrapLayer(nn.Module):
 
         self.distance_name = distance
 
-        self.classifier = classifier or torch.nn.Sequential(
-            torch.nn.Linear(encoder_output_dim*2, encoder_output_dim*4),
-            torch.nn.ReLU(),
-           torch.nn.Linear(encoder_output_dim*4, output_dim)
-
-        )
+        self.classifier = classifier or MLP(encoder_output_dim*2, encoder_output_dim*4, output_dim)
     
 
 
@@ -121,12 +136,7 @@ class BaselineMemory(nn.Module):
 
         # Red Head
         self.distance = distance
-        self.classifier = classifier or torch.nn.Sequential(
-            torch.nn.Linear(encoder_output_dim, encoder_output_dim*2),
-            torch.nn.ReLU(),
-           torch.nn.Linear(encoder_output_dim*2, output_dim)
-
-        )
+        self.classifier = classifier or MLP(encoder_output_dim, encoder_output_dim*2, output_dim)
         
     def forward(self, encoder_output:torch.Tensor, memory_set:torch.Tensor, return_weights:bool=False)->torch.Tensor:
         """Forward call of MemoryWrap.
